@@ -1,9 +1,9 @@
 package HTTP::Server::Brick;
 
 use version;
-our $VERSION = qv(0.1.3);
+our $VERSION = qv(0.1.4);
 
-# $Id: Brick.pm 367 2008-06-16 11:17:51Z aufflick $
+# $Id$
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ HTTP::Server::Brick - Simple pure perl http server for prototyping "in the style
 
 =head1 VERSION
 
-This document describes HTTP::Server::Brick version 0.1.3
+This document describes HTTP::Server::Brick version 0.1.4
 
 
 =head1 SYNOPSIS
@@ -592,7 +592,7 @@ The request object is an instance of L<HTTP::Request> with two extra properties:
 
 =item C<$req-E<gt>{mount_path}>
 
-The mounted path that was matched. This will always be identical to C<$req->uri->path>
+The mounted path that was matched. This will always be identical to C<< $req->uri->path >>
 for non-wildcard mounts.
 
 =item C<$req-E<gt>{path_info}>
@@ -673,7 +673,7 @@ prototypes with WEBrick and implemented them in (what I hope is) a Perlish way.
 
 =over
 
-=item It's version 0.1.3 - there's bound to be some bugs!
+=item It's version 0.1.4 - there's bound to be some bugs!
 
 =item The tests fail on windows due to forking limitations. I don't see any reason why the server itself won't work but I haven't tried it personally, and I have to figure out a way to test it from a test script that will work on Windows.
 
@@ -686,7 +686,7 @@ prototypes with WEBrick and implemented them in (what I hope is) a Perlish way.
 =back
 
 If you want to check out the latest development version of HTTP::Server::Brick
-you can do so from my L<CVS Server|http://cvs.pumptheory.com/viewcvs/viewcvs.cgi/perl/HTTP-Server-Brick/>.
+you can do so from my GitHub account L<http://github.com/aufflick/p5-http-server-brick>.
 
 Please report any bugs or feature requests to
 C<bug-http-server-brick@rt.cpan.org>, through the web interface at
